@@ -2,11 +2,13 @@ exampleArchive <- system.file("extdata", "examples.zip", package="rphast")
 unzip(exampleArchive, "ENr334-100k.maf")
 m <- read.msa("ENr334-100k.maf")
 mod <- phyloFit(m, tree="((hg18,(mm9,rn4)),canFam2)")
-x <- postprob.msa(sub.msa(m, start.col=41447839, end.col=41448033, refseq="hg18"), mod)
+x <- postprob.msa(sub.msa(m, start.col=41447839, end.col=41448033,
+                          refseq="hg18"), mod)
 dim(x)
 dimnames(x)
 x[,,"CCCC"]
 
 # now get postprobs for every site
-x <- postprob.msa(sub.msa(m, start.col=41447839, end.col=41448033, refseq="hg18"), mod, every.site=TRUE)
+x <- postprob.msa(sub.msa(m, start.col=41447839, end.col=41448033,
+                          refseq="hg18"), mod, every.site=TRUE)
 unlink("ENr334-100k.maf")
